#include <avr/io.h>	
#include <util/delay.h>
#include <stdint.h>
#include <stddef.h>
#include "pcf8574.h"

#ifndef LiquidCrystal_I2C_h
#define LiquidCrystal_I2C_h

// timings
#define LCD_LONG_DELAY  3


// commands
#define LCD_CLEARDISPLAY 0x01
#define LCD_RETURNHOME 0x02
#define LCD_ENTRYMODESET 0x04
#define LCD_DISPLAYCONTROL 0x08
#define LCD_CURSORSHIFT 0x10
#define LCD_FUNCTIONSET 0x20
#define LCD_SETCGRAMADDR 0x40
#define LCD_SETDDRAMADDR 0x80

// flags for display entry mode
#define LCD_ENTRYRIGHT 0x00
#define LCD_ENTRYLEFT 0x02
#define LCD_ENTRYSHIFTINCREMENT 0x01
#define LCD_ENTRYSHIFTDECREMENT 0x00

// flags for display on/off control
#define LCD_DISPLAYON 0x04
#define LCD_DISPLAYOFF 0x00
#define LCD_CURSORON 0x02
#define LCD_CURSOROFF 0x00
#define LCD_BLINKON 0x01
#define LCD_BLINKOFF 0x00

// flags for display/cursor shift
#define LCD_DISPLAYMOVE 0x08
#define LCD_CURSORMOVE 0x00
#define LCD_MOVERIGHT 0x04
#define LCD_MOVELEFT 0x00

// flags for function set
#define LCD_8BITMODE 0x10
#define LCD_4BITMODE 0x00
#define LCD_2LINE 0x08
#define LCD_1LINE 0x00
#define LCD_5x10DOTS 0x04
#define LCD_5x8DOTS 0x00

// flags for backlight control
#define LCD_BACKLIGHT 0x00
#define LCD_NOBACKLIGHT 0x80

#define En 0b00010000  // Enable bit
#define Rw 0b00100000  // Read/Write bit
#define Rs 0b01000000  // Register select bit

void i2cdisplay_init(uint8_t lcd_addr, uint8_t lcd_cols, uint8_t lcd_rows, uint8_t font_type);
void i2cdisplay_display_on();
void i2cdisplay_display_off();
void i2cdisplay_curser_on();
void i2cdisplay_curser_off();
void i2cdisplay_blink_on(); 
void i2cdisplay_blink_off();
void i2cdisplay_clear();
void i2cdisplay_home();
void i2cdisplay_set_cursor(uint8_t col, uint8_t row);
void i2cdisplay_backlight_off(void); 
void i2cdisplay_backlight_on(void);
void i2cdisplay_set_display_control(uint8_t new_val); 
void i2cdisplay_set_display_mode(uint8_t new_val);
void i2cdisplay_send_command(uint8_t value);
void i2cdisplay_send_data(uint8_t value);
void i2cdisplay_send(uint8_t value, uint8_t mode);
void i2cdisplay_write4bits(uint8_t value); 
void i2cdisplay_set_interface_pins(uint8_t data);


void i2cdisplay_write_text(const unsigned char *text);
void i2cdisplay_write_num(const uint16_t *num_ptr);


uint8_t display_control_mask;
uint8_t display_mode_mask;
uint8_t addr;
uint8_t cols;
uint8_t rows;
uint8_t display_backlight_mask;


#endif

