#include <avr/io.h>	
#include <avr/interrupt.h>
#include <util/delay.h>
#include "uart.h"
#include "I2CDisplay.h"

volatile uint16_t timebase_ms = 0x00;

void timer_init() {
	// Timer 0 konfigurieren
 	TCCR0A = (1 << WGM01); // CTC Modus
	TCCR0B |= (1 << CS00) | (1 << CS01); // Prescaler 64
	
	// 16 000 000 / 64 = 250000 Hz <=> 250 - 1 OCR0A
	OCR0A = 249;
	 
	// Compare Interrupt erlauben
	TIMSK0 |= (1 << OCIE0A);
}


int main(void) {	        
	init(); 	

	uint8_t cur_char = 0;
	while(1) {
		if (timebase_ms % 100 == 0) {
			uint16_t cur_time = timebase_ms;
			i2cdisplay_clear();  
			i2cdisplay_write_text("Time: ");
			i2cdisplay_write_num(&cur_time);
		}
	}	
}


void init() {	
	// Prepare uart
	cli();
	
    uart_init();
    timer_init();

    i2cdisplay_init(0x20, 16, 2, LCD_5x8DOTS);

  	i2cdisplay_backlight_on();

	// Enable interrupts
	sei();
}

ISR (TIMER0_COMPA_vect) {
	timebase_ms++;
}